@@ -51,35 +51,34 @@ class FfmpegProcess:
         eta_string = "unknown"
         ffmpeg_stderr = ""
 
-        print("Running FFmpeg...")
-
         with open(ffmpeg_output_file, "a") as f:
             self._process = subprocess.Popen(
                 self._ffmpeg_args,
                 stdout=subprocess.PIPE,
-                #stderr=f,
+                stderr=f,
             )
 
         input_file_info = FileInfoProvider(filepath)
-        duration_microseconds = input_file_info.get_duration() * 1_000_000
+        duration_secs = input_file_info.get_duration()
 
         progress_bar = tqdm(
-            total=duration_microseconds,
+            total=duration_secs,
+            unit="s",
             dynamic_ncols=True
         )
 
         progress_bar.clear()
-        previous_microseconds_processed = 0
+        previous_seconds_processed = 0
 
         try:
             while self._process.poll() is None:
                 line = self._process.stdout.readline().decode("utf-8")
-                # out_time_ms=3505000
+                # Format: out_time_ms=3505000
                 if "out_time_ms" in line:
-                    microseconds_processed = int(line.strip()[12:])
-                    microseconds_increase = microseconds_processed - previous_microseconds_processed
-                    progress_bar.update(microseconds_increase)
-                    previous_microseconds_processed = microseconds_processed
+                    seconds_processed = int(line.strip()[12:]) / 1_000_000
+                    seconds_increase = seconds_processed - previous_seconds_processed
+                    progress_bar.update(seconds_increase)
+                    previous_seconds_processed = seconds_processed
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
